@@ -40,7 +40,7 @@ use vars qw($idle $main $current);
 
 use base Exporter;
 
-$VERSION = 0.97;
+$VERSION = '1.0';
 
 @EXPORT = qw(async cede schedule terminate current);
 %EXPORT_TAGS = (
@@ -341,7 +341,7 @@ sub desc {
 
 L<Coro::Channel>, L<Coro::Cont>, L<Coro::Specific>, L<Coro::Semaphore>,
 L<Coro::Signal>, L<Coro::State>, L<Coro::Timer>, L<Coro::Event>,
-L<Coro::L<Coro::RWLock>, Handle>, L<Coro::Socket>.
+L<Coro::Handle>, L<Coro::RWLock>, L<Coro::Socket>.
 
 =head1 AUTHOR
 
